@@ -88,9 +88,13 @@ class CLASSIX:
     ----------
     sorting : str, {'pca', 'norm-mean', 'norm-orthant', None}，default='pca'
         Sorting method used for the aggregation phase.
+        
         - 'pca': sort data points by their first principal component
+        
         - 'norm-mean': shift data to have zero mean and then sort by 2-norm values
+        
         - 'norm-orthant': shift data to positive orthant and then sort by 2-norm values
+        
         - None: aggregate the raw data without any sorting
         
     radius : float, default=0.5
@@ -100,12 +104,15 @@ class CLASSIX:
     
     group_merging : str, {'density', 'distance'}, default='distance'
         The method for merging the groups. 
+        
         - 'density': two groups are merged if the density of data points in their intersection 
            is at least as high the smaller density of both groups. This option uses the disjoint 
            set structure to speedup agglomerate.
+        
         - 'distance': two groups are merged if the distance of their starting points is at 
            most scale*radius (the parameter above). This option uses the disjoint 
            set structure to speedup agglomerate.
+        
         For more details, we refer to [1].
     
     minPts : int, default=0
@@ -124,11 +131,7 @@ class CLASSIX:
         If allocate the outliers to the closest groups, hence the corresponding clusters. 
         If False, all outliers will be labeled as -1.
     
-    n_jobs : int, default=-1
-        This parameter only works for method called 'scc-distance', which refers to the
-        number of jobs to use for the computation by breaking down the pairwise matrix into n_jobs 
-        even slices and computing them in parallel.
-        
+
     verbose : boolean or int, default=1
         Whether print the logs or not.
              
@@ -190,8 +193,12 @@ class CLASSIX:
     #        strongly connected components.
     #     - 'mst-distance': it is also a distance based group_merging, but use minimum spanning tree instead
     #        in the second stage with cutoff_scale scale*radius.
+    # n_jobs : int, default=-1
+    #     This parameter only works for method called 'scc-distance', which refers to the
+    #     number of jobs to use for the computation by breaking down the pairwise matrix into n_jobs 
+    #     even slices and computing them in parallel.
         
-    def __init__(self, sorting="pca", radius=0.5, minPts=0, group_merging="distance", norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=1): 
+    def __init__(self, sorting="pca", radius=0.5, minPts=0, group_merging="distance", norm=True, scale=1.5, post_alloc=True, verbose=1): 
         # deprecated parameter (15/07/2021): noise_percent=0, distance_scale=1, eta=1, cython=True
         # eta (deprecated): float, default=1.0
         #     the value for the density-based groups merging, the groups will 
@@ -237,7 +244,7 @@ class CLASSIX:
         self.norm = norm # usually, we do not use this parameter
         self.scale = scale # For distance measure, usually, we do not use this parameter
         self.post_alloc = post_alloc
-        self.n_jobs = n_jobs
+        # self.n_jobs = n_jobs
         self.clean_index = None
         self.connected_pairs = None
         self.cluster_color = None
@@ -304,13 +311,13 @@ class CLASSIX:
         self.clean_index = np.full(self.data.shape[0], True) # claim clean data indices
         # clustering
         self.labels_ = self.clustering(
-            data=self.data, 
-            agg_labels=self.agg_labels, 
-            splist=self.splist, 
-            sorting=self.sorting, 
-            radius=self.radius, 
-            method=self.group_merging, # eta=self.eta, distance_scale=self.distance_scale, 
-            minPts=self.minPts # percent=self.noise_percent, noise_scale=self.noise_scale,
+                            data=self.data, 
+                            agg_labels=self.agg_labels, 
+                            splist=self.splist, 
+                            sorting=self.sorting, 
+                            radius=self.radius, 
+                            method=self.group_merging, # eta=self.eta, distance_scale=self.distance_scale, 
+                            minPts=self.minPts # percent=self.noise_percent, noise_scale=self.noise_scale,
         ) 
         return self
 
@@ -756,11 +763,15 @@ class CLASSIX:
         replace_name : str or list (optional)
             Replace the index with name. 
             * For example: as for indices 1 and 1300 we have 
-            >>> classix.explain(1, 1300, showsplist=True, plot=False, figstyle="seaborn") # or classix.explain(obj1, obj4)
+            
+            ``classix.explain(1, 1300, plot=False, figstyle="seaborn") # or classix.explain(obj1, obj4)``
+            
             The data point 1 is in group 9 and the data point 1300 is in group 8, both of which were merged into cluster #0. 
             These two groups are connected via groups 9 -> 2 -> 8.
             * if we specify the replace name, then the output will be
-            >>> classix.explain(1, 1300, showsplist=False, replace_name=["Peter Meyer", "Anna Fields"], plot=False, figstyle="seaborn")
+            
+            ``classix.explain(1, 1300, replace_name=["Peter Meyer", "Anna Fields"], figstyle="seaborn")``
+            
             The data point Peter Meyer is in group 9 and the data point Anna Fields is in group 8, both of which were merged into cluster #0. 
             These two groups are connected via groups 9 -> 2 -> 8.
 
@@ -1435,12 +1446,10 @@ class CLASSIX:
         
         
     
-    def visualize_linkage(self, scale=1.5, figsize=(8,8), labelsize=24, 
-                          norm=True, markersize=320, plot_boundary=False, bound_color='red', path='img', fmt='pdf'):
+    def visualize_linkage(self, scale=1.5, figsize=(8,8), labelsize=24, norm=True, markersize=320, plot_boundary=False,
+                                             bound_color='red', path='.', fmt='pdf'):
         
-        distm, n_components, labels = visualize_connections(self.splist, radius=self.radius, 
-                                                            scale=round(scale,2), 
-                                                            n_jobs=-1)
+        distm, n_components, labels = visualize_connections(self.splist, radius=self.radius, scale=round(scale,2))
         # plt.figure(figsize=figsize)
         plt.rcParams['axes.facecolor'] = 'white'
         if norm:
@@ -1632,8 +1641,8 @@ class CLASSIX:
         if value <= 0:
             raise ValueError(
                 "Please feed an correct value (>0) for tolerance")
-        if value > 1:
-            warnings.warn("Might lead to bad aggregation", DeprecationWarning)
+        # if value > 1:
+        #     warnings.warn("Might lead to bad aggregation", DeprecationWarning)
         self._radius = value
     
     
@@ -1833,8 +1842,18 @@ class CLASSIX:
 #     return labels, splist, agg_centers
 
 
-def visualize_connections(splist, radius=0.5, scale=1.5, n_jobs=-1):
-    distm = pairwise_distances(splist[:,3:], Y=None, metric='euclidean', n_jobs=n_jobs)
+
+def pairwise_distance(X):
+    distm = np.zeros((X.shape[0], X.shape[0]))
+    for i in range(X.shape[0]):
+        for j in range(i, X.shape[0]):
+            distm[i, j] = distm[j, i] = norm(X[i,:]-X[j,:], ord=2)
+    return distm
+
+
+
+def visualize_connections(splist, radius=0.5, scale=1.5):
+    distm = pairwise_distances(splist[:,3:])
     tol = radius*scale
     distm = (distm <= tol).astype(int)
     n_components, labels = connected_components(csgraph=distm, directed=False, return_labels=True)
@@ -1984,6 +2003,8 @@ def return_csr_matrix_indices(csr_matrix):
     _sparsetools.expandptr(shape_dim1, csr_matrix.indptr, indices)
     return np.array(list(zip(indices, length_range)))
 
+
+
 # deprecated (24/07/2021) -> for scipy shortest distance use
 # def get_shortest_path(predecessors, i, j):
 #     """Get the shortest path between two nodes in the graph"""
